@@ -148,13 +148,17 @@ class JunosDevice(linux.LinuxDevice):
             suffix2 = ' | no-more' if ("show" in c) else ''
 
             if "commit" in c:
-                t = self.thread(target=self.sleep,args=(kwargs.get('timeout', 120), 50, '>', "commit"))
+                #t = self.thread(target=self.sleep,
+                #        args=(kwargs.get('timeout', 120), 50, '>', "commit"))
+                self.log("Wait for at most %d seconds to commit."
+                        %(kwargs.get('timeout', 120)))
 
             output = linux.LinuxDevice.cmd(self, c + suffix1 + suffix2, **kwargs)
-            if "commit" in c:
-                # Wait the commit finish in case of HA.
-                self.terminate_loop = True
-                #linux.LinuxDevice.cmd(self, "show | compare rollback 1 | no-more", **kwargs)
+            #if "commit" in c:
+            #    # Wait the commit finish in case of HA.
+            #    self.terminate_loop = True
+            #    #linux.LinuxDevice.cmd(self,
+            #    #        "show | compare rollback 1 | no-more", **kwargs)
 
             if kwargs.get('parse', None):
                 #self["log_level"] = self["log_level"] + 1
@@ -854,17 +858,17 @@ class JunosDevice(linux.LinuxDevice):
             set usp flow local-debug-buf state 1
             """
         policy_debug_config = '''
-            debug usp policy application error
-            debug usp policy config error
-            debug usp policy context error
-            debug usp policy entity error
-            debug usp policy general error
-            debug usp policy ipc error
-            debug usp policy tlv error
-            debug usp policy jtree error
-            debug usp policy lookup error
-            debug usp policy prefix error
-            debug usp policy state error
+            debug usp policy application verbose
+            debug usp policy config verbose
+            debug usp policy context verbose
+            debug usp policy entity verbose
+            debug usp policy general verbose
+            debug usp policy ipc verbose
+            debug usp policy tlv verbose
+            debug usp policy jtree verbose
+            debug usp policy lookup verbose
+            debug usp policy prefix verbose
+            debug usp policy state verbose
             '''
 
 if __name__ == '__main__':
